**Example 1: 创建或修改计算结果存储路径**



Input: 

```
tccli dlc CreateStoreLocation --cli-unfold-argument  \
    --StoreLocation cosn://ricky-1301xxx708/test2/
```

Output: 
```
{
    "Response": {
        "RequestId": "4aa0c835-d58e-4faa-b7d9-be9b34a9e931"
    }
}
```

